Class: Google::Apis::AreainsightsV1::AreaInsightsService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::AreainsightsV1::AreaInsightsService
- Defined in:
- lib/google/apis/areainsights_v1/service.rb
Overview
Places Aggregate API
Places Aggregate API.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://areainsights.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#compute_insights(compute_insights_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AreainsightsV1::ComputeInsightsResponse
This method lets you retrieve insights about areas using a variety of filter such as: area, place type, operating status, price level and ratings.
-
#initialize ⇒ AreaInsightsService
constructor
A new instance of AreaInsightsService.
Constructor Details
#initialize ⇒ AreaInsightsService
Returns a new instance of AreaInsightsService.
47 48 49 50 51 52 |
# File 'lib/google/apis/areainsights_v1/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-areainsights_v1', client_version: Google::Apis::AreainsightsV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/areainsights_v1/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/areainsights_v1/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#compute_insights(compute_insights_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AreainsightsV1::ComputeInsightsResponse
This method lets you retrieve insights about areas using a variety of filter
such as: area, place type, operating status, price level and ratings.
Currently "count" and "places" insights are supported. With "count" insights
you can answer questions such as "How many restaurant are located in
California that are operational, are inexpensive and have an average rating of
at least 4 stars" (see insight enum for more details). With "places"
insights, you can determine which places match the requested filter. Clients
can then use those place resource names to fetch more details about each
individual place using the Places API.
81 82 83 84 85 86 87 88 89 90 |
# File 'lib/google/apis/areainsights_v1/service.rb', line 81 def compute_insights(compute_insights_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1:computeInsights', ) command.request_representation = Google::Apis::AreainsightsV1::ComputeInsightsRequest::Representation command.request_object = compute_insights_request_object command.response_representation = Google::Apis::AreainsightsV1::ComputeInsightsResponse::Representation command.response_class = Google::Apis::AreainsightsV1::ComputeInsightsResponse command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |