Class: Google::Apis::AreainsightsV1::Circle

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/areainsights_v1/classes.rb,
lib/google/apis/areainsights_v1/representations.rb,
lib/google/apis/areainsights_v1/representations.rb

Overview

A circle is defined by a center point and radius in meters.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Circle

Returns a new instance of Circle.



49
50
51
# File 'lib/google/apis/areainsights_v1/classes.rb', line 49

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#lat_lngGoogle::Apis::AreainsightsV1::LatLng

An object that represents a latitude/longitude pair. This is expressed as a pair of doubles to represent degrees latitude and degrees longitude. Unless specified otherwise, this object must conform to the WGS84 standard. Values must be within normalized ranges. Corresponds to the JSON property latLng



35
36
37
# File 'lib/google/apis/areainsights_v1/classes.rb', line 35

def lat_lng
  @lat_lng
end

#placeString

Format: Must be in the format places/PLACE_ID, where PLACE_ID is the unique identifier of a place. For example: places/ChIJgUbEo8cfqokR5lP9_Wh_DaM . Corresponds to the JSON property place

Returns:

  • (String)


42
43
44
# File 'lib/google/apis/areainsights_v1/classes.rb', line 42

def place
  @place
end

#radiusFixnum

Optional. The radius of the circle in meters Corresponds to the JSON property radius

Returns:

  • (Fixnum)


47
48
49
# File 'lib/google/apis/areainsights_v1/classes.rb', line 47

def radius
  @radius
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54
55
56
57
58
# File 'lib/google/apis/areainsights_v1/classes.rb', line 54

def update!(**args)
  @lat_lng = args[:lat_lng] if args.key?(:lat_lng)
  @place = args[:place] if args.key?(:place)
  @radius = args[:radius] if args.key?(:radius)
end